@@ -18,7 +18,12 @@ The public API of this package consists only of the objects exposed through this
 Direct access to sub-modules is not officially supported, so may be affected by
 backwards-incompatible changes without notice.
 """
-from __future__ import absolute_import, division, print_function, unicode_literals
+from __future__ import (
+    absolute_import,
+    division,
+    print_function,
+    unicode_literals,
+)
 
 from .bloch import (
     display_bloch_sphere,
@@ -27,8 +32,15 @@ from .bloch import (
     print_bloch_sphere_data,
     print_bloch_sphere_data_qutrit,
 )
-from .controls import plot_controls, plot_sequences, plot_smooth_controls
-from .discriminators import plot_discriminator, plot_xdata
+from .controls import (
+    plot_controls,
+    plot_sequences,
+    plot_smooth_controls,
+)
+from .discriminators import (
+    plot_discriminator,
+    plot_xdata,
+)
 from .filter_functions import plot_filter_functions
 from .style import get_qctrl_style
 
@@ -46,4 +58,4 @@ __all__ = [
     "plot_xdata",
 ]
 
-__version__ = "2.3.2"
+__version__ = "2.4.3"
