@@ -16,7 +16,10 @@ Functions for handling Q-CTRL styling.
 """
 
 from contextlib import contextmanager
-from typing import Any, Dict
+from typing import (
+    Any,
+    Dict,
+)
 
 from cycler import cycler
 from matplotlib.style import context
@@ -37,7 +40,7 @@ def get_qctrl_style() -> Dict[str, Any]:
     dict
         The dictionary representing the Q-CTRL style.
     """
-    style = {}
+    style: Dict[str, Any] = {}
 
     # Used for legend text.
     style["text.color"] = TEXT_COLOR
